# metaheuristicpy

A Python-based package of Metaheuristic Optimization Algorithms for Solving Continous and Discrete Optimization Problem

<hr>

# Cite

If you think this package is useful, please cite this paper in your project: <br>
[1] Bimantara, I.M.S., Sanjaya ER, N., Purwitasari, D. (2023). Character Entity Recognition Using Hybrid Binary-Particle Swarm Optimization and Conditional Random Field on Balinese Folklore Text. In: Delir Haghighi, P., et al. Information Integration and Web Intelligence. iiWAS 2023. Lecture Notes in Computer Science, vol 14416. Springer, Cham. https://doi.org/10.1007/978-3-031-48316-5_15 <br>
[2] Bimantara, I. M. S., & Widiartha, I. M. (2023). Optimization of K-Means Clustering Using Particle Swarm Optimization Algorithm for Grouping Traveler Reviews Data on Tripadvisor Sites. Jurnal Ilmiah Kursor, 12(1), 1-10. <br>
[3] Supriana, I. W., Raharja, M. A., Bimantara, I. M. S., & Bramantya, D. (2021). Implementasi dua model crossover pada algoritma genetika untuk optimasi penggunaan ruang perkuliahan. Jurnal RESISTOR (Rekayasa Sistem Komputer), 4(2), 167-177. <br>
[4] BIMANTARA, I Made Satria et al. Implementasi Generalized Learning Vector Quantization (GLVQ) dan Particle Swarm Optimization (PSO) Untuk Klasifikasi Kanker Payudara. JELIKU (Jurnal Elektronik Ilmu Komputer Udayana), [S.l.], v. 10, n. 4, p. 307-318, may 2022. ISSN 2654-5101. Available at: <https://ojs.unud.ac.id/index.php/jlk/article/view/85746>. Date accessed: 31 may 2025. doi: https://doi.org/10.24843/JLK.2022.v10.i04.p01. <br>

# Contributors and Developer

- I Made Satria Bimantara
- email: satriabimantara.idm@gmail.com
